@@ -9,16 +9,16 @@
 #' * It checks the package on R-release and R-devel.
 #' * It uses the `--as-cran` argument to `R CMD check`.
 #' * It requires all dependencies, including suggested ones.
+#' 
+#' @details This function is wrapped by `devtools::check_rhub()` which you 
+#' might find useful if you load `devtools` via your .Rprofile (see `usethis::use_devtools()`).
 #'
 #' @param check_args Arguments for `R CMD check`. By default `--as-cran`
 #'   is used.
-#' @param env_vars Environment variables to set on the builder. By default
-#'   `_R_CHECK_FORCE_SUGGESTS_=true` is set, to require all packages used.
-#'   `_R_CHECK_CRAN_INCOMING_USE_ASPELL_=true` is also set, to use the
+#' @param env_vars Character vecctor of environment variables to set on the builder. 
+#'   By default `_R_CHECK_FORCE_SUGGESTS_="true"` is set, to require all packages used.
+#'   `_R_CHECK_CRAN_INCOMING_USE_ASPELL_="true"` is also set, to use the
 #'   spell checker.
-#' @param platforms Character vector of platform ids to use
-#'   (see [platforms()]), or `NULL`. If `NULL`, then a set of default
-#'   platforms will be selected, see below.
 #' @param ... Additional arguments are passed to [check()].
 #' @inheritParams check
 #' @return An [rhub_check] object.
@@ -42,7 +42,7 @@ check_for_cran <- function(
 
   platforms <- platforms %||% default_cran_check_platforms(path)
 
-  check(path = path, platform = platforms, email = email,
+  check(path = path, platforms = platforms, email = email,
         check_args = check_args, env_vars = env_vars, ...)
 }
 
